<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>AddImage</name>
    <message>
        <location filename="../src/add_image.cpp" line="87"/>
        <source>Open Image</source>
        <translation>Bild auswählen</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="59"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="68"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="70"/>
        <source>Beveled borders</source>
        <translation>Abgeschrägte Kanten</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="73"/>
        <source>Drop shadows</source>
        <translation>Schlagschatten</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="77"/>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="96"/>
        <source>Background:</source>
        <translation>Hintergrund:</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="97"/>
        <source>Shadow:</source>
        <translation>Schatten:</translation>
    </message>
    <message>
        <location filename="../src/appearance_dialog.cpp" line="98"/>
        <source>Highlight:</source>
        <translation>Hervorgehoben:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <location filename="../src/board.cpp" line="187"/>
        <location filename="../src/board.cpp" line="293"/>
        <location filename="../src/board.cpp" line="361"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="187"/>
        <location filename="../src/board.cpp" line="293"/>
        <source>Missing image.</source>
        <translation>Bild nicht gefunden.</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="194"/>
        <location filename="../src/board.cpp" line="269"/>
        <location filename="../src/main.cpp" line="146"/>
        <source>Please Wait</source>
        <translation>Bitte warten</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="216"/>
        <location filename="../src/board.cpp" line="368"/>
        <source>Loading image...</source>
        <translation>Bild wird geladen...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="222"/>
        <source>Generating puzzle...</source>
        <translation>Puzzle wird erzeugt...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="228"/>
        <location filename="../src/board.cpp" line="242"/>
        <source>Creating pieces...</source>
        <translation>Teile werden erzeugt...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="281"/>
        <source>Loading puzzle...</source>
        <translation>Puzzle wird geladen...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="306"/>
        <source>Unknown data format</source>
        <translation>Unbekanntes Dateiformat</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="356"/>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Unbekanntes Element &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="361"/>
        <source>Error parsing XML file.

%1</source>
        <translation>Fehler beim Parsen der XML-Datei.

%1</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="372"/>
        <source>Loading pieces...</source>
        <translation>Teile werden geladen...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="454"/>
        <source>Retrieving pieces...</source>
        <translation>Teile werden geholt...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="994"/>
        <source>Placing pieces...</source>
        <translation>Teile werden gelegt...</translation>
    </message>
    <message>
        <location filename="../src/board.cpp" line="1326"/>
        <source>Success</source>
        <translation>Fertiggestellt</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <location filename="../src/choose_game_dialog.cpp" line="38"/>
        <source>Choose Game</source>
        <translation>Spiel auswählen</translation>
    </message>
    <message>
        <location filename="../src/choose_game_dialog.cpp" line="52"/>
        <source>Current Games</source>
        <translation>Aktuelle Spiele</translation>
    </message>
    <message>
        <location filename="../src/choose_game_dialog.cpp" line="57"/>
        <source>New Game</source>
        <translation>Neues Spiel</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <location filename="../src/image_properties_dialog.cpp" line="39"/>
        <source>Image Properties</source>
        <translation>Bildeigenschaften</translation>
    </message>
    <message>
        <location filename="../src/image_properties_dialog.cpp" line="72"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../src/image_properties_dialog.cpp" line="73"/>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="50"/>
        <source>Select application language:</source>
        <translation>Anwendungssprache auswählen:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="53"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systemeinstellung&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Note</source>
        <translation>Hinweis</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="183"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Bitte starten Sie diese Anwendung neu um den Wechsel der Sprache auszuführen.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <location filename="../src/new_game_tab.cpp" line="105"/>
        <source>Add Image</source>
        <translation>Bild hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="109"/>
        <location filename="../src/new_game_tab.cpp" line="290"/>
        <source>Remove Image</source>
        <translation>Bild entfernen</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="113"/>
        <source>Image Properties</source>
        <translation>Bildeigenschaften</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="132"/>
        <location filename="../src/new_game_tab.cpp" line="383"/>
        <source>%L1 pieces</source>
        <translation>%L1 Teile</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="193"/>
        <source>Copying images...</source>
        <translation>Bilder werden kopiert...</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="286"/>
        <source>Remove selected image?</source>
        <translation>Ausgewähltes Bild entfernen?</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="288"/>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Ausgewähltes Bild entfernen?

Es existieren gespeicherte Spiele, die dieses Bild benutzen und die ebenfalls gelöscht werden.</translation>
    </message>
    <message>
        <location filename="../src/new_game_tab.cpp" line="493"/>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <location filename="../src/open_game_tab.cpp" line="86"/>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="89"/>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 Teile %2 %3% fertiggestellt</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="105"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="148"/>
        <source>Delete Game</source>
        <translation>Spiel löschen</translation>
    </message>
    <message>
        <location filename="../src/open_game_tab.cpp" line="148"/>
        <source>Delete selected game?</source>
        <translation>Ausgewähltes Spiel löschen?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <location filename="../src/overview.cpp" line="38"/>
        <source>Overview</source>
        <translation>Übersicht</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <location filename="../src/tag_manager.cpp" line="50"/>
        <source>Add Tag</source>
        <translation>Tag hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="54"/>
        <source>Remove Tag</source>
        <translation>Tag löschen</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="59"/>
        <source>Untagged</source>
        <translation>Nicht getaggt</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="88"/>
        <source>All Images</source>
        <translation>Alle Bilder</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="208"/>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="232"/>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="232"/>
        <source>Remove selected tag?</source>
        <translation>Ausgewähltes Tag löschen?</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="273"/>
        <source>Sorry</source>
        <translation>Sorry</translation>
    </message>
    <message>
        <location filename="../src/tag_manager.cpp" line="273"/>
        <source>A tag with that name already exists.</source>
        <translation>Ein Tag mit diesem Namen existiert bereits.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/main.cpp" line="147"/>
        <location filename="../src/window.cpp" line="50"/>
        <location filename="../src/window.cpp" line="286"/>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="80"/>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="84"/>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Teile holen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="84"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="88"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="81"/>
        <source>&amp;Choose...</source>
        <translation>&amp;Auswählen...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="91"/>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="92"/>
        <source>Zoom &amp;In</source>
        <translation>Ver&amp;größern</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="92"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <source>Zoom &amp;Out</source>
        <translation>Ver&amp;kleinern</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="95"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="98"/>
        <source>Best &amp;Fit</source>
        <translation>In Fenster &amp;einpassen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="101"/>
        <source>Show O&amp;verview</source>
        <translation>Ü&amp;bersicht zeigen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="101"/>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="107"/>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="111"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="113"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="116"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="117"/>
        <source>&amp;Appearance...</source>
        <translation>&amp;Erscheinungsbild...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="118"/>
        <source>&amp;Language...</source>
        <translation>&amp;Sprache...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="120"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="121"/>
        <source>&amp;Controls</source>
        <translation>&amp;Steuerung</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="123"/>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="125"/>
        <source>About &amp;Qt</source>
        <translation>Info über &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="252"/>
        <source>Controls</source>
        <translation>Steuerung</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="259"/>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile aufnehmen:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="260"/>
        <location filename="../src/window.cpp" line="262"/>
        <source>Left Click or Space</source>
        <translation>Linksklick oder Leertaste</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="261"/>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile ablegen:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="263"/>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile auswählen:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>Left Drag</source>
        <translation>Ziehen mit linker Maustaste</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teile drehen:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Rechtsklick, Strg + Linksklick, oder R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="267"/>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzle verschieben:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="268"/>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Mittelklick, Umschalt + Linksklick, oder Pfeiltasten</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="269"/>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puzzlegröße ändern:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="270"/>
        <source>Scrollwheel or +/-</source>
        <translation>Mausrad oder +/-</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="271"/>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zeiger bewegen:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="272"/>
        <source>Move mouse or W,A,D,S</source>
        <translation>Maus bewegen oder W, A, D, S</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="285"/>
        <source>About Tetzle</source>
        <translation>Info über Tetzle</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="287"/>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Eine Puzzlespiel mit Tetrominos als Puzzleteilen</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="288"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="289"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Veröffentlicht unter der &lt;a href=%1&gt;GPL-3&lt;/a&gt;-Lizenz</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <location filename="../src/zoom_slider.cpp" line="38"/>
        <source>??%</source>
        <translation>??%</translation>
    </message>
    <message>
        <location filename="../src/zoom_slider.cpp" line="63"/>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
</context>
</TS>
